#ifndef _IDTAG_H
#define _IDTAG_H

/*
 * This source code is provided to you with NO WARRANTY and NO LICENSE.
 * You may do with it as you please, and I cannot be held responsible for
 * any outcome of the use of this code.  It is hereby released into the
 * public domain.
 * 	- Robey Pointer
 */

typedef struct {
    char title[121];
    char artist[81];
    char album[81];
    char year[5];
    char comment[81];
    char unknown;	/* probably the "genre" tag...? */
} ID3Tag;

/*
 * read an id3 tag from the end of an mp3 file.
 * if an id3x tag is present, that will be silently read also.  (id3x
 *     extends the length of several of the id3 fields.)
 * returns 1 on success, 0 on failure
 */
int id3_read(int fd, ID3Tag *tag);

/*
 * write an id3 tag to the end of an mp3 file.
 * if any of the tag fields are long enough to require an id3x tag also,
 *     the id3x tag is silently written too.
 * if 'write_only' is set, i won't check for existing tags -- i'll just
 *     smack new tags on the end of the file.  this is useful if you just
 *     created this mp3 file yourself (and only have the file open for
 *     writing).  if you use 'write_only' on an mp3 that already has an
 *     id3 tag, i'll be appending new ones and the old tags will occupy
 *     dead space, which is wasteful, but probably mostly harmless.
 * returns 1 on success, 0 on failure
 */
int id3_write(int fd, ID3Tag *tag, int write_only);

#endif
